@@ -1,15 +1,8 @@
 import React, {PropTypes} from 'react';
 import CatalogItem from './catalog-item';
 import {Seq} from 'immutable'
-
-const STYLE_TITLE ={
-  color: "#2e2f33",
-};
-
-const STYLE_CONTAINER = {
-  padding: "0 20px",
-  overflowY: "scroll"
-};
+import ContentContainer from '../style/content-container';
+import ContentTitle from '../style/content-title';
 
 const STYLE_ITEMS = {
   display: "flex",
@@ -19,15 +12,15 @@ const STYLE_ITEMS = {
 
 export default function CatalogList({width, height, state}, {catalog}) {
   return (
-    <div style={{width, height, ...STYLE_CONTAINER}} onWheel={event => event.stopPropagation()}>
-      <h2 style={STYLE_TITLE}>Catalog</h2>
+    <ContentContainer width={width} height={height}>
+      <ContentTitle>Layer config</ContentTitle>
       <div style={STYLE_ITEMS}>
         {Seq(catalog.elements)
           .entrySeq()
           .filter(([name, element]) => element.prototype !== 'areas')
           .map(([name, element]) => <CatalogItem key={name} element={element}/>)}
       </div>
-    </div>
+    </ContentContainer>
   )
 }
 
